import { select } from 'd3';

export const main = (container) => {
  const width = container.clientWidth;
  const height = container.clientHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', '#000');

  const stars = [
    { x: 50, y: 30 },
    { x: 180, y: 80 },
    { x: 300, y: 20 },
    { x: 420, y: 60 },
    { x: 550, y: 50 },
    { x: 700, y: 40 },
    { x: 800, y: 50 },
    { x: 500, y: 35 },
    { x: 645, y: 40 },
  ];

  svg
    .selectAll('polygon')
    .data(stars)
    .join('polygon')
    .attr('points', starPoints)
    .attr('fill', '#FFF');

  function starPoints(d) {
    const innerRadius = 5;
    const outerRadius = 15;
    const points = 5;
    let angle = Math.PI / 2;

    const starCoords = [];

    for (let i = 0; i < 2 * points; i++) {
      const radius =
        i % 2 === 0 ? outerRadius : innerRadius;
      starCoords.push(
        `${d.x + radius * Math.cos(angle)},${
          d.y - radius * Math.sin(angle)
        }`,
      );
      angle += (2 * Math.PI) / (2 * points);
    }

    return starCoords.join(' ');
  }

  // Draw Pumpkin
  const pumpkin = {
    x: width / 2,
    y: height / 2,
    width: 120,
    height: 80,
    fill: '#FFA500',
  };

  svg
    .append('ellipse')
    .attr('cx', pumpkin.x)
    .attr('cy', pumpkin.y + 20)
    .attr('rx', pumpkin.width / 2)
    .attr('ry', pumpkin.height / 2)
    .attr('fill', pumpkin.fill);

  // Draw Pumpkin Face
  svg
    .append('circle')
    .attr('cx', pumpkin.x - 20)
    .attr('cy', pumpkin.y + 5)
    .attr('r', 5)
    .attr('fill', '#000');

  svg
    .append('circle')
    .attr('cx', pumpkin.x + 20)
    .attr('cy', pumpkin.y + 5)
    .attr('r', 5)
    .attr('fill', '#000');

  svg
    .append('rect')
    .attr('x', pumpkin.x - 15)
    .attr('y', pumpkin.y + 25)
    .attr('width', 30)
    .attr('height', 5)
    .attr('fill', '#000');

  svg
    .append('rect')
    .attr('x', pumpkin.x - 5)
    .attr('y', pumpkin.y - 25)
    .attr('width', 10)
    .attr('height', 10)
    .attr('fill', '#008000'); // Dark Green color for stem

  const skeleton = {
    head: { cx: width / 3, cy: height / 3, r: 20 },
    body: {
      x: width / 3 - 10,
      y: height / 3 + 20,
      width: 20,
      height: 40,
    },
    arms: [
      {
        x1: width / 3 - 10,
        y1: height / 3 + 30,
        x2: width / 3 - 30,
        y2: height / 3 + 20,
      },
      {
        x1: width / 3 + 10,
        y1: height / 3 + 30,
        x2: width / 3 + 30,
        y2: height / 3 + 20,
      },
    ],
    legs: [
      {
        x1: width / 3 - 10,
        y1: height / 3 + 60,
        x2: width / 3 - 20,
        y2: height / 3 + 80,
      },
      {
        x1: width / 3 + 10,
        y1: height / 3 + 60,
        x2: width / 3 + 20,
        y2: height / 3 + 80,
      },
    ],
  };

  // Draw Head Outline
  svg
    .append('circle')
    .attr('cx', skeleton.head.cx)
    .attr('cy', skeleton.head.cy)
    .attr('r', skeleton.head.r)
    .attr('fill', 'none')
    .attr('stroke', '#FFFFFF')
    .attr('stroke-width', 2);

  // Draw Body Outline
  svg
    .append('rect')
    .attr('x', skeleton.body.x)
    .attr('y', skeleton.body.y)
    .attr('width', skeleton.body.width)
    .attr('height', skeleton.body.height)
    .attr('fill', 'none')
    .attr('stroke', '#FFFFFF')
    .attr('stroke-width', 2);

  skeleton.arms.forEach((arm) => {
    svg
      .append('line')
      .attr('x1', arm.x1)
      .attr('y1', arm.y1)
      .attr('x2', arm.x2)
      .attr('y2', arm.y2)
      .attr('stroke', '#FFFFFF')
      .attr('stroke-width', 2);
  });

  skeleton.legs.forEach((leg) => {
    svg
      .append('line')
      .attr('x1', leg.x1)
      .attr('y1', leg.y1)
      .attr('x2', leg.x2)
      .attr('y2', leg.y2)
      .attr('stroke', '#FFFFFF')
      .attr('stroke-width', 2);
  });
};
